import { Disclosure } from '@lukas.j.han/sd-jwt-util';
import { Hasher, HasherAndAlg } from '@lukas.j.han/sd-jwt-type';
import { HasherSync, HasherAndAlgSync } from '@lukas.j.han/sd-jwt-type/src/type';

declare const decodeJwt: <H extends Record<string, any>, T extends Record<string, any>>(jwt: string) => {
    header: H;
    payload: T;
    signature: string;
};
declare const splitSdJwt: (sdjwt: string) => {
    jwt: string;
    disclosures: string[];
    kbJwt?: string;
};
declare const decodeSdJwt: (sdjwt: string, hasher: Hasher) => Promise<DecodedSDJwt>;
declare const decodeSdJwtSync: (sdjwt: string, hasher: HasherSync) => DecodedSDJwt;
declare const getClaims: <T>(rawPayload: any, disclosures: Array<Disclosure<any>>, hasher: Hasher) => Promise<T>;
declare const getClaimsSync: <T>(rawPayload: any, disclosures: Array<Disclosure<any>>, hasher: HasherSync) => T;
declare const unpackArray: (arr: Array<any>, map: Record<string, Disclosure<any>>, prefix?: string) => {
    unpackedObj: any;
    disclosureKeymap: Record<string, string>;
};
declare const unpackObj: (obj: any, map: Record<string, Disclosure<any>>, prefix?: string) => {
    unpackedObj: any;
    disclosureKeymap: Record<string, string>;
};
declare const createHashMapping: (disclosures: Array<Disclosure<any>>, hash: HasherAndAlg) => Promise<Record<string, Disclosure<any>>>;
declare const createHashMappingSync: (disclosures: Array<Disclosure<any>>, hash: HasherAndAlgSync) => Record<string, Disclosure<any>>;
declare const getSDAlgAndPayload: (sdjwtPayload: any) => {
    _sd_alg: string;
    payload: any;
};
declare const unpack: (sdjwtPayload: any, disclosures: Array<Disclosure<any>>, hasher: Hasher) => Promise<{
    unpackedObj: any;
    disclosureKeymap: Record<string, string>;
}>;
declare const unpackSync: (sdjwtPayload: any, disclosures: Array<Disclosure<any>>, hasher: HasherSync) => {
    unpackedObj: any;
    disclosureKeymap: Record<string, string>;
};
type DecodedSDJwt = {
    jwt: {
        header: Record<string, any>;
        payload: Record<string, any>;
        signature: string;
    };
    disclosures: Array<Disclosure<any>>;
    kbJwt?: {
        header: Record<string, any>;
        payload: Record<string, any>;
        signature: string;
    };
};

export { type DecodedSDJwt, createHashMapping, createHashMappingSync, decodeJwt, decodeSdJwt, decodeSdJwtSync, getClaims, getClaimsSync, getSDAlgAndPayload, splitSdJwt, unpack, unpackArray, unpackObj, unpackSync };
